<div style="display : flex ; justify-content : center ;" align="center">

# Hasta

</div>

----------------------------------------------------

<div style="display : flex ; justify-content : center ;" align="center">

<!-- License -->
<a href="LICENSE.md">
    <img src="https://img.shields.io/badge/License-MIT-%23117a1a?style=for-the-badge&logo=opensourceinitiative" />
</a>

<!-- Python -->
<a href="https://www.python.org/downloads/release/python-399/">
    <img src="https://img.shields.io/badge/Python-3.9.9-blue?style=for-the-badge&logo=python" />
</a>

<!--Code Size-->
<a>
    <img src="https://img.shields.io/github/languages/code-size/anokidev/hasta?color=lightblue&logo=codesandbox&style=for-the-badge" />
</a>

<!--Downloads-->
<a>
    <img src="https://img.shields.io/github/downloads/anokidev/hasta/total?color=green&logo=github&style=for-the-badge" />
</a>

<!--Version-->
<a>
    <img src="" />

</div>

----------------------------------------------------

**General :**

A simple WSGI Server, implemented in CPython 3.9.9 .

----------------------------------------------------

**Functions :**

This software can :

- Handles HTTP request, one at a time.
- Fullfills Python WSGI specification.
- Supports Python web framework.

----------------------------------------------------

**Installation :**

Hasta is not available via PIP yet.

----------------------------------------------------

**Compabillity :**

- Supports Python 3.9.9 .
- Doesn't support PyPy .

----------------------------------------------------

**Version :**

- Current stable version : None.
- Current beta release : None.
- Current alpha release : None.
- Current pre-alpha release : v0.0.0 Pre - Alpha 2 ( SHORT NAME : v0.0.0-pa2 ) - [ BRANCH NAME : v0.0.0/pa2/r ] .

----------------------------------------------------

**Tasks :**

Read [TASKS.md](/.github/NOTES/TASKS.md) for more info.

----------------------------------------------------

**Contributing :**

Read [CONTRIBUTING.md](/.github/COMMUNITY/CONTRIBUTING.md) for more info.

----------------------------------------------------

**License :**

Licensed in MIT License. Read [LICENSE.md](/LICENSE.md) for more info.
